﻿
CREATE TABLE actionlog (
  alogid int  primary key,
  gsid int ,
  userid int ,
  logname varchar(255),
  logmessage varchar(255),
  rawobj varchar2(4000),
  logdate int,
  sid int ,
  rectype varchar(255),
  recid int ,
  wssdone int
);

create index actionlog_logdate on actionlog(logdate);
create index actionlog_userid on actionlog(userid);
create index actionlog_wssdone on actionlog(wssdone);
create index actionlog_gsid on actionlog(gsid);

create sequence actionlog_seq start with 1 increment by 1 nomaxvalue;

create or replace trigger actionlog_trigger before insert on actionlog
for each row 
begin
select actionlog_seq.nextval into :new.alogid from dual;
end;
/

commit;

CREATE TABLE gss (
  gsid int  primary key,
  gsname varchar(255) ,
  stripecustomerid varchar(255) ,
  gsexpiry int ,
  gstier int 
);

create index gss_gsname on gss(gsname);
create index gss_gsexpiry on gss(gsexpiry);

create sequence gss_seq start with 1 increment by 1 nomaxvalue;

create or replace trigger gss_trigger before insert on gss
for each row 
begin
select gss_seq.nextval into :new.gsid from dual;
end;
/

INSERT INTO gss VALUES (1, 'Default Instance', '', 0, 0);

commit;

CREATE TABLE users (
  userid int primary key,
  gsid int  ,
  login varchar(255) ,
  dispname varchar(255) ,
  active int  DEFAULT '1',
  virtualuser int ,
  password varchar(255) ,
  passreset int ,
  groupnames varchar2(4000),
  keyfilehash varchar(255),
  needkeyfile int ,
  usesms int ,
  smscell varchar(255) ,  
  smscode varchar(255) ,  
  certhash varchar(255),
  needcert int ,
  certname varchar(255)
);

CREATE UNIQUE INDEX users_login ON users (login);
create index users_gsid on users(gsid);
create index users_active on users(active);
create index users_virtualuser on users(virtualuser);

create sequence users_seq start with 101 increment by 1 nomaxvalue;

create or replace trigger users_trigger before insert on users
for each row 
begin
select users_seq.nextval into :new.userid from dual;
end;
/

-- MCrypt --
-- INSERT INTO users VALUES (101,1,'admin','Admin',1,0,'FWZvboZOBbEqPhDQ5r04E4jfMgw4Q93kyDkx1xT/4z6jfngMPmGU3qvlfkT/Vp58OoZOvYwYUUDM9bfdvB+KEQ==',0,'users|admins|reportsettings|systemplateuse|systemplate|accounts|dbadmin|upgrademods',null,0,null,0,null);
-- OpenSSL --
INSERT INTO users VALUES (101,1,'admin','Admin',1,0,'uSAsxyX3v44q3+/4Md7lzkhaNlIvTHFTMkZsN1lFRWVMRzB2UlloZTJqWHRjSG9mRDgybTI3U0xZUjhzYVhUeDlUZ2dLQ283QkUrVmExaEY=',0,'users|admins|reportsettings|systemplateuse|systemplate|accounts|dbadmin|upgrademods',null,0,0,'','',null,0,null);

commit;


CREATE TABLE templates (
  templateid int  primary key,
  templatename varchar(255) ,
  templatetypeid int  ,
  templatetext varchar2(4000)
);

create index templates_templatetypeid on templates(templatetypeid);

create sequence templates_seq start with 101 increment by 1 nomaxvalue;

create or replace trigger templates_trigger before insert on templates
for each row 
begin
select templates_seq.nextval into :new.templateid from dual;
end;
/

commit;

CREATE TABLE templatetypes (
  templatetypeid int  primary key,
  gsid int ,
  templatetypename varchar(255) ,
  templatetypekey varchar(255),
  activetemplateid int ,
  templatetypegroup varchar(255) ,
  plugins varchar(255) ,
  classes varchar(255)
);

create index templatetypes_templatetypekey on templatetypes(templatetypekey);
create index templatetypes_activetemplateid on templatetypes(activetemplateid);
create index templatetypes_gsid on templatetypes(gsid);

create sequence templatetypes_seq start with 1 increment by 1 nomaxvalue;

create or replace trigger templatetypes_trigger before insert on templatetypes
for each row 
begin
select templatetypes_seq.nextval into :new.templatetypeid from dual;
end;
/

commit;

CREATE TABLE templatevars (
  templatevarid int  primary key,
  templatevarname varchar(255) ,
  templatevardesc varchar(255) ,
  templatetypeid int
);

create sequence templatevars_seq start with 1 increment by 1 nomaxvalue;

create or replace trigger templatevars_trigger before insert on templatevars
for each row 
begin
select templatevars_seq.nextval into :new.templatevarid from dual;
end;
/

commit;
    
CREATE TABLE reports (
  reportid int  primary key,
  gsid int  ,
  reportname_en varchar(255),
  reportgroup_en varchar(255),
  reportdesc_en varchar2(4000),
  reportname_de varchar(255) ,
  reportgroup_de varchar(255) ,
  reportdesc_de varchar2(4000) ,
  reportname_pt varchar(255) ,
  reportgroup_pt varchar(255) ,
  reportdesc_pt varchar2(4000) ,
  reportname_zh varchar(255) ,
  reportgroup_zh varchar(255) ,
  reportdesc_zh varchar2(4000) ,
  reportfunc varchar(255),
  reportkey varchar(255) ,
  reportgroupnames varchar(255) ,
  gyrosys int 
);

create sequence reports_seq start with 1 increment by 1 nomaxvalue;

create or replace trigger reports_trigger before insert on reports
for each row 
begin
select reports_seq.nextval into :new.reportid from dual;
end;
/

create index reports_reportkey on reports(reportkey);
create index reports_gsid on reports(gsid);


INSERT INTO reports VALUES (1, 0, 'Activity Log', 'Security', 'This report is mostly used by system administrators for diagnostic purposes.', 'Aktivitätsprotokoll', 'Sicherheit', '', 'Registro de Atividade', '', 'admins', '1', '????', '????', '', 'actionlog', 'admins|reportsettings|systemplateuse|systemplate', 1);
     
commit;
